@@ -2,7 +2,7 @@ import json
 
 from django.conf import settings
 from django.contrib.humanize.templatetags.humanize import intcomma
-from django.db import models, transaction
+from django.db import models
 from django.db.models import Max
 from django.utils.functional import cached_property
 from django.utils.module_loading import import_string
@@ -10,6 +10,7 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.documents.models.document_models import Document
 from mayan.apps.documents.models.document_type_models import DocumentType
+from mayan.apps.documents.tasks import task_document_file_upload
 from mayan.apps.events.classes import (
     EventManagerMethodAfter, EventManagerSave
 )
@@ -39,8 +40,8 @@ IMPORT_ERROR_EXCLUSION_TEXTS = (
 
 
 class BackendModelMixin(models.Model):
-    # TODO: Use common.model_mixins.BackendModelMixin after upgrade to version
-    # 4.0.
+    # TODO: Use common.model_mixins.BackendModelMixin after upgrade to
+    # version 4.0.
     backend_path = models.CharField(
         max_length=128,
         help_text=_('The dotted Python path to the backend class.'),
@@ -398,25 +399,30 @@ class ImportSetupItem(models.Model):
         document_type = self.import_setup.document_type
         label = self.data.get(backend_class.item_label, self.id)
 
-        with transaction.atomic():
-            try:
-                with shared_uploaded_file.open() as file_object:
-                    document = document_type.new_document(
-                        file_object=file_object, label=label
-                    )
-            except Exception as exception:
-                self.state = ITEM_STATE_ERROR
-                self.state_data = str(exception)
-                self.save()
-                if settings.DEBUG:
-                    raise
-            else:
-                self.state = ITEM_STATE_COMPLETE
-                self.state_data = ''
-                self.save()
-                shared_uploaded_file.delete()
+        try:
+            document = Document.objects.create(
+                document_type=document_type, label=label
+            )
+        except Exception as exception:
+            self.state = ITEM_STATE_ERROR
+            self.state_data = str(exception)
+            self.save()
+            if settings.DEBUG:
+                raise
+        else:
+            self.state = ITEM_STATE_COMPLETE
+            self.state_data = ''
+            self.save()
 
-        return document
+            task_document_file_upload.apply_async(
+                kwargs={
+                    'document_id': document.pk,
+                    'filename': document.label,
+                    'shared_uploaded_file_id': shared_uploaded_file.pk,
+                }
+            )
+
+            return document
 
     @cached_property
     def data(self):
@@ -457,22 +463,21 @@ class ImportSetupItem(models.Model):
         shared_uploaded_file = None
 
         if self.state == ITEM_STATE_NONE:
-            with transaction.atomic():
-                try:
-                    backend_instance = self.import_setup.get_backend_instance()
-                    shared_uploaded_file = backend_instance.item_process(
-                        identifier=self.identifier, data=self.data,
-                    )
-                except Exception as exception:
-                    self.state = ITEM_STATE_ERROR
-                    self.state_data = str(exception)
-                    self.save()
-                    if settings.DEBUG:
-                        raise
-                else:
-                    self.state = ITEM_STATE_DOWNLOADED
-                    self.state_data = ''
-                    self.save()
+            try:
+                backend_instance = self.import_setup.get_backend_instance()
+                shared_uploaded_file = backend_instance.item_process(
+                    identifier=self.identifier, data=self.data
+                )
+            except Exception as exception:
+                self.state = ITEM_STATE_ERROR
+                self.state_data = str(exception)
+                self.save()
+                if settings.DEBUG:
+                    raise
+            else:
+                self.state = ITEM_STATE_DOWNLOADED
+                self.state_data = ''
+                self.save()
 
             if shared_uploaded_file:
                 document = self.create_document(
