@@ -1,13 +1,13 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.task_manager.classes import CeleryQueue
-from mayan.apps.task_manager.workers import worker_medium
+from mayan.apps.task_manager.workers import worker_c
 
 queue_importer = CeleryQueue(
-    label=_('Importer'), name='importer', worker=worker_medium
+    label=_('Importer'), name='importer', worker=worker_c
 )
 queue_model_filer = CeleryQueue(
-    label=_('Model filer'), name='filer', worker=worker_medium
+    label=_('Model filer'), name='filer', worker=worker_c
 )
 
 queue_importer.add_task_type(
@@ -16,7 +16,7 @@ queue_importer.add_task_type(
 )
 queue_importer.add_task_type(
     label=_('Process an import setup item'),
-    dotted_path='importer.tasks.task_import_setup_process'
+    dotted_path='importer.tasks.task_import_setup_item_process'
 )
 queue_importer.add_task_type(
     label=_('Populate the items of an import setup'),
