@@ -7,15 +7,15 @@ from django.template import RequestContext
 from django.urls import reverse, reverse_lazy
 from django.utils.translation import ungettext, ugettext_lazy as _
 
-from mayan.apps.common.generics import (
+from mayan.apps.documents.views.document_views import DocumentListView
+from mayan.apps.storage.models import SharedUploadedFile
+from mayan.apps.views.generics import (
     ConfirmView, FormView, MultipleObjectConfirmActionView,
     SingleObjectDeleteView, SingleObjectDynamicFormCreateView,
     SingleObjectDynamicFormEditView, SingleObjectDownloadView,
     SingleObjectListView
 )
-from mayan.apps.common.mixins import ExternalObjectMixin
-from mayan.apps.common.models import SharedUploadedFile
-from mayan.apps.documents.views.document_views import DocumentListView
+from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from .classes import ImportSetupActionBackend, ImportSetupBackend, ModelFiler
 from .forms import (
@@ -47,7 +47,7 @@ logger = logging.getLogger(name=__name__)
 
 
 class ImportSetupActionCreateView(
-    ExternalObjectMixin, SingleObjectDynamicFormCreateView
+    ExternalObjectViewMixin, SingleObjectDynamicFormCreateView
 ):
     external_object_class = ImportSetup
     external_object_permission = permission_import_setup_edit
@@ -173,7 +173,7 @@ class ImportSetupActionEditView(SingleObjectDynamicFormEditView):
         )
 
 
-class ImportSetupActionListView(ExternalObjectMixin, SingleObjectListView):
+class ImportSetupActionListView(ExternalObjectViewMixin, SingleObjectListView):
     external_object_class = ImportSetup
     external_object_permission = permission_import_setup_view
     external_object_pk_url_kwarg = 'import_setup_id'
@@ -206,7 +206,7 @@ class ImportSetupActionListView(ExternalObjectMixin, SingleObjectListView):
         return self.external_object.actions.all()
 
 
-class ImportSetupActionBackendSelectionView(ExternalObjectMixin, FormView):
+class ImportSetupActionBackendSelectionView(ExternalObjectViewMixin, FormView):
     external_object_class = ImportSetup
     external_object_permission = permission_import_setup_edit
     external_object_pk_url_kwarg = 'import_setup_id'
@@ -404,8 +404,8 @@ class ImportSetupPopulateView(MultipleObjectConfirmActionView):
     post_action_redirect = reverse_lazy(
         viewname='importer:import_setup_list'
     )
-    success_message = _('%(count)d import setup populate queued.')
-    success_message_plural = _('%(count)d import setups populate queued.')
+    success_message = _('%(count)d import setup preparation queued.')
+    success_message_plural = _('%(count)d import setups preparation queued.')
 
     def get_extra_context(self):
         queryset = self.object_list
@@ -417,11 +417,11 @@ class ImportSetupPopulateView(MultipleObjectConfirmActionView):
                 'the import backend, the size of the source repository, '
                 'and the bandwidth between Mayan EDMS and the source '
                 'repository, it may take between a few minutes to a few '
-                'days for the entire population process to complete.'
+                'days for the entire preparation process to complete.'
             ),
             'title': ungettext(
-                singular='Populate the selected import setup?',
-                plural='Populate the selected import setups?',
+                singular='Prepare the selected import setup?',
+                plural='Prepare the selected import setups?',
                 number=queryset.count()
             )
         }
@@ -430,7 +430,7 @@ class ImportSetupPopulateView(MultipleObjectConfirmActionView):
             result.update(
                 {
                     'object': queryset.first(),
-                    'title': _('Populate import setup: %s') % queryset.first()
+                    'title': _('Prepare import setup: %s') % queryset.first()
                 }
             )
 
@@ -488,7 +488,7 @@ class ImportSetupProcessView(MultipleObjectConfirmActionView):
             messages.warning(
                 message=_(
                     'Import setup "%s" does not have any item to process. '
-                    'Use the populate action first.'
+                    'Use the prepare action first.'
                 ) % instance, request=self.request
             )
         else:
@@ -511,7 +511,7 @@ class ImportSetupItemDeleteView(MultipleObjectConfirmActionView):
             'delete_view': True,
             'import_setup': self.object_list.first().import_setup,
             'message': _(
-                'You can add this item again by executing the populate '
+                'You can add this item again by executing the prepare '
                 'action.'
             ),
             'navigation_object_list': ('import_setup', 'object'),
@@ -550,7 +550,7 @@ class ImportSetupItemDeleteView(MultipleObjectConfirmActionView):
 
 
 class ImportSetupItemDocumentListView(
-    ExternalObjectMixin, DocumentListView
+    ExternalObjectViewMixin, DocumentListView
 ):
     external_object_class = ImportSetupItem
     external_object_permission = permission_import_setup_view
@@ -583,7 +583,7 @@ class ImportSetupItemDocumentListView(
         return context
 
 
-class ImportSetupItemListView(ExternalObjectMixin, SingleObjectListView):
+class ImportSetupItemListView(ExternalObjectViewMixin, SingleObjectListView):
     external_object_class = ImportSetup
     external_object_permission = permission_import_setup_view
     external_object_pk_url_kwarg = 'import_setup_id'
@@ -663,7 +663,7 @@ class ImportSetupItemProcessView(MultipleObjectConfirmActionView):
         )
 
 
-class ImportSetupItemLoadView(ExternalObjectMixin, FormView):
+class ImportSetupItemLoadView(ExternalObjectViewMixin, FormView):
     external_object_class = ImportSetup
     external_object_object_permission = permission_model_filer_load
     external_object_pk_url_kwarg = 'import_setup_id'
@@ -709,7 +709,7 @@ class ImportSetupItemLoadView(ExternalObjectMixin, FormView):
         }
 
 
-class ImportSetupItemSaveConfirmView(ExternalObjectMixin, ConfirmView):
+class ImportSetupItemSaveConfirmView(ExternalObjectViewMixin, ConfirmView):
     external_object_class = ImportSetup
     external_object_object_permission = permission_model_filer_save
     external_object_pk_url_kwarg = 'import_setup_id'
@@ -756,7 +756,7 @@ class ImportSetupItemSaveDownloadView(SingleObjectDownloadView):
         return '{}.csv'.format(self.object)
 
 
-class ImportSetupLogListView(ExternalObjectMixin, SingleObjectListView):
+class ImportSetupLogListView(ExternalObjectViewMixin, SingleObjectListView):
     external_object_class = ImportSetup
     external_object_permission = permission_import_setup_view
     external_object_pk_url_kwarg = 'import_setup_id'
